summaryrefslogtreecommitdiffstats
path: root/kmail/kmmainwin.cpp
diff options
context:
space:
mode:
authorMichele Calgaro <[email protected]>2025-01-20 18:26:41 +0900
committerMichele Calgaro <[email protected]>2025-01-20 18:26:41 +0900
commitaae5ebe5008a41fe4a4767092d7e17600abf6725 (patch)
tree97002e11e1564bceeda4fb4b3b04164bb9e72286 /kmail/kmmainwin.cpp
parent69779eb81c20b80b56ab698f44a944efd6107a74 (diff)
downloadtdepim-aae5ebe5008a41fe4a4767092d7e17600abf6725.tar.gz
tdepim-aae5ebe5008a41fe4a4767092d7e17600abf6725.zip
Use tdeApprename/tdeapp
Signed-off-by: Michele Calgaro <[email protected]>
Diffstat (limited to 'kmail/kmmainwin.cpp')
-rw-r--r--kmail/kmmainwin.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kmail/kmmainwin.cpp b/kmail/kmmainwin.cpp
index d1abdab6e..120b1606a 100644
--- a/kmail/kmmainwin.cpp
+++ b/kmail/kmmainwin.cpp
@@ -33,7 +33,7 @@ KMMainWin::KMMainWin(TQWidget *)
// modal subdialogs will only affect this dialog, not the other windows
setWFlags( getWFlags() | WGroupLeader );
- kapp->ref();
+ tdeApp->ref();
(void) new TDEAction( i18n("New &Window"), "window-new", 0,
this, TQ_SLOT(slotNewMailReader()),
@@ -86,7 +86,7 @@ KMMainWin::~KMMainWin()
{
saveMainWindowSettings(KMKernel::config(), "Main Window");
KMKernel::config()->sync();
- kapp->deref();
+ tdeApp->deref();
if ( !kmkernel->haveSystemTrayApplet() ) {
// Check if this was the last KMMainWin
@@ -103,7 +103,7 @@ KMMainWin::~KMMainWin()
if ( not_withdrawn == 0 ) {
kdDebug(5006) << "Closing last KMMainWin: stopping mail check" << endl;
// Running TDEIO jobs prevent kapp from exiting, so we need to kill them
// if they are only about checking mail (not important stuff like moving messages)
kmkernel->abortMailCheck();
kmkernel->acctMgr()->cancelMailCheck();
@@ -206,10 +206,10 @@ void KMMainWin::slotConfigChanged()
//-----------------------------------------------------------------------------
bool KMMainWin::queryClose()
{
- if ( kapp->sessionSaving() )
+ if ( tdeApp->sessionSaving() )
writeConfig();
- if ( kmkernel->shuttingDown() || kapp->sessionSaving() || mReallyClose )
+ if ( kmkernel->shuttingDown() || tdeApp->sessionSaving() || mReallyClose )
return true;
return kmkernel->canQueryClose();
}
@@ -103,7 +103,7 @@ KMMainWin::~KMMainWin()
if ( not_withdrawn == 0 ) {
kdDebug(5006) << "Closing last KMMainWin: stopping mail check" << endl;
- // Running TDEIO jobs prevent kapp from exiting, so we need to kill them
+ // Running TDEIO jobs prevent tdeApp from exiting, so we need to kill them
// if they are only about checking mail (not important stuff like moving messages)
kmkernel->abortMailCheck();